@@ -6,7 +6,7 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::Bug;
-$BZ::Client::Bug::VERSION = '2.0_4';
+$BZ::Client::Bug::VERSION = '2.0_5';
 use parent qw( BZ::Client::API );
 
 # See https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/Bug.html
@@ -16,13 +16,13 @@ use parent qw( BZ::Client::API );
 
 sub fields {
     my($class, $client, $params) = @_;
-    $client->log('debug', 'BZ::Client::Bug::fields: Retrieving');
+    $client->log('debug', __PACKAGE__ . '::fields: Retrieving');
     my $result = $class->api_call($client, 'Bug.fields', $params);
     my $fields = $result->{'fields'};
     if (!$fields || 'ARRAY' ne ref($fields)) {
         $class->error($client, 'Invalid reply by server, expected array of fields.');
     }
-    $client->log('debug', 'BZ::Client::Bug::fields: Got ' . scalar @$fields);
+    $client->log('debug', __PACKAGE__ . '::fields: Got ' . scalar @$fields);
     return wantarray ? @$fields : $fields
 }
 
@@ -35,13 +35,13 @@ sub legal_values {
     if (!$values || 'ARRAY' ne ref($values)) {
         $class->error($client, 'Invalid reply by server, expected array of values.');
     }
-    $client->log('debug', 'BZ::Client::Bug::legal_values: Got ' . join(',', @$values));
+    $client->log('debug', __PACKAGE__ . '::legal_values: Got ' . join(',', @$values));
     return wantarray ? @$values : $values
 }
 
 sub get {
     my($class, $client, $params) = @_;
-    $client->log('debug', 'BZ::Client::Bug::get: Asking');
+    $client->log('debug', __PACKAGE__ . '::get: Asking');
     $params->{'permissive'} = BZ::Client::XMLRPC::boolean::TRUE()
         if $params->{'permissive'};
     my $result = $class->api_call($client, 'Bug.get', $params);
@@ -53,19 +53,19 @@ sub get {
     for my $bug (@$bugs) {
         push(@result, BZ::Client::Bug->new(%$bug));
     }
-    $client->log('debug', 'BZ::Client::Bug::get: Got ' . scalar(@result));
+    $client->log('debug', __PACKAGE__ . '::get: Got ' . scalar(@result));
     return wantarray ? @result : \@result
 }
 
 sub history {
     my($class, $client, $params) = @_;
-    $client->log('debug', 'BZ::Client::Bug::history: Retrieving');
+    $client->log('debug', __PACKAGE__ . '::history: Retrieving');
     my $result = $class->api_call($client, 'Bug.history', $params);
     my $bugs = $result->{'bugs'};
     if (!$bugs || 'ARRAY' ne ref($bugs)) {
         $class->error($client, 'Invalid reply by server, expected array of bug changes.');
     }
-    $client->log('debug', 'BZ::Client::Bug::history: Got ' . scalar @$bugs);
+    $client->log('debug', __PACKAGE__ . '::history: Got ' . scalar @$bugs);
     return wantarray ? @$bugs : $bugs
 }
 
@@ -109,6 +109,7 @@ sub create {
     if (!$id) {
         $class->error($client, 'Invalid reply by server, expected bug ID.');
     }
+    $client->log('debug', __PACKAGE__ . "::create: Made $id");
     return $id
 }
 
@@ -120,6 +121,7 @@ sub update {
     if (!$bugs || 'ARRAY' ne ref($bugs)) {
         $class->error($client, 'Invalid reply by server, expected array of bug details.');
     }
+    $client->log('debug', __PACKAGE__ . '::update: Updated stuff');
     return wantarray ? @$bugs : $bugs
 }
 
@@ -131,6 +133,7 @@ sub update_see_also {
     if (!$changes || 'HASH' ne ref($changes)) {
         $class->error($client, 'Invalid reply by server, expected hash of changed bug details.');
     }
+    $client->log('debug', __PACKAGE__ . '::update_see_also: Updated stuff');
     return wantarray ? %$changes : $changes
 }
 
@@ -142,6 +145,7 @@ sub update_tags {
     if (!$changes || 'HASH' ne ref($changes)) {
         $class->error($client, 'Invalid reply by server, expected hash of changed bug details.');
     }
+    $client->log('debug', __PACKAGE__ . '::update_tags: Updated stuff');
     return wantarray ? %$changes : $changes
 }
 
@@ -331,7 +335,7 @@ BZ::Client::Bug - Client side representation of a bug in Bugzilla
 
 =head1 VERSION
 
-version 2.0_4
+version 2.0_5
 
 =head1 SYNOPSIS
 
@@ -343,6 +347,85 @@ This class provides methods for accessing and managing bugs in Bugzilla.
 
   my $bugs = BZ::Client::Bug->get( $client, $ids );
 
+=head1 COMMON PARAMETERS
+
+Many Webservice methods take similar arguments. Instead of re-writing the documentation for each method, we document the parameters here, once, and then refer back to this documentation from the individual methods where these parameters are used.
+
+=head2 Limiting What Fields Are Returned
+
+Many methods return an array of structs with various fields in the structs.
+(For example, L<get> in L<BZ::Client::Bug> returns a list of bugs that have fields like
+L<id>, L<summary>, L<creation_time>, etc.)
+
+These parameters allow you to limit what fields are present in the structs, to possibly improve performance or save some bandwidth.
+
+=head3 include_fields
+
+I<include_fields> (array) - An array of strings, representing the (case-sensitive) names of fields in the return value. Only the fields specified in this hash will be returned, the rest will not be included.
+
+If you specify an empty array, then this function will return empty hashes.
+
+Invalid field names are ignored.
+
+Example:
+
+ BZ::Client::User->get( $client,
+    { ids => [1], include_fields => ['id', 'name'] })
+
+would return something like:
+
+ [{ id => 1, name => 'user@domain.com' }]
+
+=head3 exclude_fields
+
+I<exclude_fields> (array) - An array of strings, representing the (case-sensitive) names of fields in the return value. The fields specified will not be included in the returned hashes.
+
+If you specify all the fields, then this function will return empty hashes.
+
+Some RPC calls support specifying sub fields. If an RPC call states that it support sub field restrictions, you can restrict what information is returned within the first field. For example, if you call Product.get with an include_fields of components.name, then only the component name would be returned (and nothing else). You can include the main field, and exclude a sub field.
+
+Invalid field names are ignored.
+
+Specifying fields here overrides L<include_fields>, so if you specify a field in both, it will be excluded, not included.
+
+Example:
+
+ BZ::Client::User->get( $client,
+    { ids => [1], exclude_fields => ['name'] })
+
+would return something like:
+
+ [{ id => 1, real_name => 'John Smith' }]
+
+=head3 shortcuts
+
+There are several shortcut identifiers to ask for only certain groups of fields to be returned or excluded.
+
+=over 4
+
+=item _all
+
+All possible fields are returned if _all is specified in include_fields.
+
+=item _default
+
+These fields are returned if include_fields is empty or _default is specified. All fields described in the documentation are returned by default unless specified otherwise.
+
+=item _extra
+
+These fields are not returned by default and need to be manually specified in include_fields either by field name, or using _extra.
+
+=item _custom
+
+Only custom fields are returned if _custom is specified in include_fields. This is normally specific to bug objects and not relevant for other returned objects.
+
+=back
+
+Example:
+
+ BZ::Client::User->get( $client,
+    { ids => [1], include_fields => ['_all'] })
+
 =head1 UTILITY FUNCTIONS
 
 This section lists the utility functions provided by this module.
@@ -1062,9 +1145,22 @@ Gets or sets the current status of the bug.
 
 Gets or sets the summary of this bug.
 
+=head1 ATTACHMENTS & COMMENTS
+
+These are implemented by other modules.
+
+See L<BZ::Client::Bug::Attachment> and L<BZ::Client::Bug::Comment>
+
+=head1 TODO
+
+Bugzilla 5.0. introduced the C<search_comment_tags> and C<update_comment_tags> methods,
+these are yet to be specifically implemented.
+
 =head1 SEE ALSO
 
-  L<BZ::Client>, L<BZ::Client::API>, L<Bugzilla API|https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/Bug.html>
+L<BZ::Client>, L<BZ::Client::Bug::Attachment>, L<BZ::Client::Bug::Comment>
+
+L<BZ::Client::API>, L<Bugzilla API|https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/Bug.html>
 
 =head1 AUTHORS
 
