@@ -6,7 +6,7 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::Bug::Attachment;
-$BZ::Client::Bug::Attachment::VERSION = '2.0_4';
+$BZ::Client::Bug::Attachment::VERSION = '2.0_5';
 use parent qw( BZ::Client::API );
 
 # See https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/Bug.html
@@ -192,7 +192,7 @@ BZ::Client::Bug::Attachment - Client side representation of an Attachment to a B
 
 =head1 VERSION
 
-version 2.0_4
+version 2.0_5
 
 =head1 SYNOPSIS
 
@@ -337,7 +337,7 @@ I<comment> (string) - A comment to add along with this attachment.
 
 =item is_patch
 
-I<is_patcb> (boolean) - True if Bugzilla should treat this attachment as a patch. If you specify this, you do not need to specify a L<content_type>. The L<content_type> of the attachment will be forced to C<text/plain>.
+I<is_patch> (boolean) - True if Bugzilla should treat this attachment as a patch. If you specify this, you do not need to specify a L<content_type>. The L<content_type> of the attachment will be forced to C<text/plain>.
 
 Defaults to False if not specified.
 
@@ -427,7 +427,7 @@ You did not specify a valid for the L<file_name> argument.
 
 =item 604 - Summary Required
 
-You did not specify a value for the summary argument.
+You did not specify a value for the L<summary> argument.
 
 =item 606 - Empty Data
 
@@ -483,7 +483,182 @@ You do not have access to the I<bug_id> you specified.
 
 =head2 update
 
-TODO
+This allows you to update attachment metadata in Bugzilla.
+
+Actual Bugzilla API method is "update_attachments".
+
+Added in Bugzilla 5.0.
+
+=head3 Parameters
+
+=over 4
+
+=item ids
+
+I<ids> (array) - An array that can contain both bug IDs and bug aliases. All of the attachments (that are visible to you) will be returned for the specified bugs.
+
+=item file_name
+
+I<file_name> (string) Required - The "file name" that will be displayed in the UI for this attachment.
+
+=item summary
+
+I<summary> (string) Required - A short string describing the attachment.
+
+=item comment
+
+I<comment> (string) - A comment to add along with this attachment.
+
+=item content_type
+
+I<content_type> (string) -  The MIME type of the attachment, like text/plain or image/png.
+
+=item is_patch
+
+I<is_patch> (boolean) - True if Bugzilla should treat this attachment as a patch. If you specify this, you do not need to specify a L<content_type>. The L<content_type> of the attachment will be forced to C<text/plain>.
+
+=item is_private
+
+I<is_private> (boolean) - True if the attachment should be private (restricted to the "insidergroup"), False if the attachment should be public.
+
+=item is_obsolete
+
+I<is_obsolete> (boolean) - True if the attachment is obsolete, False otherwise.
+
+=item flags
+
+An array of hashes with flags to add to the attachment. to create a flag, at least the status and the type_id or name must be provided. An optional requestee can be passed if the flag type is requestable to a specific user.
+
+=over 4
+
+=item name
+
+I<name> (string) - The name of the flag type.
+
+=item type_id
+
+I<type_id> (int) - THe internal flag type id.
+
+=item status
+
+I<status> (string) - The flags new status  (i.e. "?", "+", "-" or "X" to clear a flag).
+
+=item requestee
+
+I<requestee> (string) - The login of the requestee if the flag type is requestable to a specific user.
+
+=item id
+
+I<id> (int) - Use C<id> to specify the flag to be updated. You will need to specify the C<id> if more than one flag is set of the same name.
+
+=item new
+
+I<new> (boolean) - Set to true if you specifically want a new flag to be created.
+
+=back
+
+=back
+
+=head3 Returns
+
+An array of hashes with the following fields:
+
+=over 4
+
+=item id
+
+I<id> (int) The id of the attachment that was updated.
+
+=item last_change_time
+
+I<last_change_time> (dateTime) - The exact time that this update was done at, for this attachment. If no update was done (that is, no fields had their values changed and no comment was added) then this will instead be the last time the attachment was updated.
+
+=item changes
+
+I<changes> (hash) - The changes that were actually done on this bug. The keys are the names of the fields that were changed, and the values are a hash with two keys:
+
+=over 4
+
+=item added
+
+I<added> (string) - The values that were added to this field. possibly a comma-and-space-separated list if multiple values were added.
+
+=item removed
+
+I<removed> (string) - The values that were removed from this field.
+
+=back
+
+=back
+
+Here is an example of what a return value might look like:
+
+  [
+    {
+      id    => 123,
+      last_change_time => '2010-01-01T12:34:56',
+      changes => {
+        summary => {
+          removed => 'Sample ptach',
+          added   => 'Sample patch'
+        },
+        is_obsolete => {
+          removed => '0',
+          added   => '1',
+        }
+      },
+    }
+  ]
+
+=head3 Errors
+
+=over 4
+
+=item 100 - Invalid Bug Alias
+
+If you specified an alias and there is no bug with that alias.
+
+=item 101 - Invalid Bug ID
+
+The bug_id you specified doesn't exist in the database.
+
+=item 102 - Access Denied
+
+You do not have access to the I<bug_id> you specified.
+
+=item 129 - Flag Status Invalid
+
+The flag status is invalid.
+
+=item 130 - Flag Modification Denied
+
+You tried to request, grant, or deny a flag but only a user with the required permissions may make the change.
+
+=item 131 - Flag not Requestable from Specific Person
+
+You can't ask a specific person for the flag.
+
+=item 133 - Flag Type not Unique
+
+The flag type specified matches several flag types. You must specify the type id value to update or add a flag.
+
+=item 134 - Inactive Flag Type
+
+The flag type is inactive and cannot be used to create new flags.
+
+=item 601 - Invalid MIME Type
+
+You specified a L<content_type> argument that was blank, not a valid MIME type, or not a MIME type that Bugzilla accepts for attachments.
+
+=item 603 - File Name Not Specified
+
+You did not specify a valid for the L<file_name> argument.
+
+=item 604 - Summary Required
+
+You did not specify a value for the L<summary> argument.
+
+=back
 
 =head2 new
 
